@@ -1,39 +1,34 @@
 package Weed::Array;
 
-use Weed 'X3DArray [ ]', 'isArray';
-
-our $VERSION = '0.011';
+use Weed 'X3DArray [ ]';
 
 use Algorithm::Numerical::Shuffle;
-#Set::Array;
 
 use overload
-  'bool' => 'getLength',
-
-  'int' => 'getLength',
-  '0+'  => 'getLength',
-
-  '<>' => sub { shift @{ $_[0] } },
+  'bool' => 'length',
   ;
 
 sub new {
-	my $self = $_[0];
-	my $type = ref($self) || $self;
-	return bless $_[1] || [], $type;
+	my $this = shift->NEW;
+	$this->setValue(@_);
+	return $this;
 }
 
-sub getClone {
-	my $clone = $_[0]->new;
-	@$clone = @{ $_[0] };
-	return $clone;
+sub copy { $_[0]->new( $_[0]->getValue ) }
+
+sub getValue { @{ $_[0] } }
+
+sub setValue {
+	my $this = shift;
+	@$this = @_;
+	return;
 }
 
 use overload '<=>' => sub {
 	my ( $a, $b, $r, $c ) = @_;
 	( $a, $b ) = ( $b, $a ) if $r;
 
-	return $a <=> @$b unless isArray($a);    # [] <=> scalar
-	return @$a <=> $b unless isArray($b);    # [] <=> scalar
+	return @$a <=> $b unless ref $b;    # [] <=> scalar
 
 	return $c if $c = $#$a <=> $#$b;
 
@@ -48,9 +43,6 @@ use overload 'cmp' => sub {
 	my ( $a, $b, $r, $c ) = @_;
 	( $a, $b ) = ( $b, $a ) if $r;
 
-	return $a cmp "$b" unless isArray($a);    # [] <=> scalar
-	return "$a" cmp $b unless isArray($b);    # [] <=> scalar
-
 	return $c if $c = $#$a <=> $#$b;
 
 	for ( my $i = 0 ; $i < @$a ; ++$i ) {
@@ -60,54 +52,50 @@ use overload 'cmp' => sub {
 	return 0;
 };
 
-sub getLength { scalar @{ $_[0] } }
-sub setLength { $#{ $_[0] } = $_[1] - 1; return }
-
-sub isArray {
-	UNIVERSAL::isa( $_[0], __PACKAGE__ )
-	  or
-	  UNIVERSAL::isa( $_[0], 'ARRAY' )
-}
-
-sub sort { $_[0]->new( [ sort { $a <=> $b } @{ $_[0] } ] ) }
-
-sub random { $_[0]->new( scalar Algorithm::Numerical::Shuffle::shuffle( [ @{ $_[0] } ] ) ) }
-
 sub clear { @{ $_[0] } = () }
 
-sub toString { # also in MFBool & MFString
-	my ($this) = @_;
+sub length { scalar @{ $_[0] } }
 
-	my $string = '';
+use Sort::ArbBiLex (
+	'schmancy_sort' =>
+	  "
+	  0 1 2 3 4 5 6 7 8 9
+     a A              
+     b B
+     c C  
+     d D  
+     e E        
+     f F
+     g G
+     h H
+     i I        
+     j J
+     k K
+     l L
+     m M
+     n N  
+     o O            
+     p P
+     q Q
+     r R
+     s S 
+     t T  
+     u U        
+     v V
+     w W
+     x X
+     y Y   
+     z Z
+    "
+);
 
-	if (@$this) {
-		if ($#$this) {
-			$string .= X3DGenerator->open_bracket;
-			X3DGenerator->inc;
-			$string .= X3DGenerator->tidy_indent ? X3DGenerator->tidy_break : X3DGenerator->tidy_space;
-			$string .= X3DGenerator->tidy_indent;
-			$string .= join
-			  X3DGenerator->tidy_comma .
-			  ( X3DGenerator->tidy_indent ? X3DGenerator->tidy_break : X3DGenerator->tidy_space ) .
-			  X3DGenerator->tidy_indent,
-			  @$this;
-			$string .= X3DGenerator->tidy_indent ? X3DGenerator->tidy_break : X3DGenerator->tidy_space;
-			X3DGenerator->dec;
-			$string .= X3DGenerator->tidy_indent;
-			$string .= X3DGenerator->close_bracket;
-		}
-		else {
-			$string .= $this->[0];
-		}
-	}
-	else {
-		$string .= X3DGenerator->open_bracket;
-		$string .= X3DGenerator->tidy_space;
-		$string .= X3DGenerator->close_bracket;
-	}
+use overload 'neg' => sub {
+	$_[0]->new( schmancy_sort( @{ $_[0] } ) )
+};
 
-	return $string;
-}
+use overload '~' => sub { $_[0]->new( Algorithm::Numerical::Shuffle::shuffle( @{ $_[0] } ) ) };
+
+sub toString { join ', ', @{ $_[0] } }
 
 1;
 __END__
