@@ -1,18 +1,15 @@
 package Weed::Parse::String;
 use Weed::Perl;
 
-our $VERSION = '0.009';
-
 use Weed::RegularExpressions '$_string';
 
 use Exporter 'import';
 
-our @EXPORT_OK = qw.parseString string.;
-
-sub parseString { &string( $_[0] ) }
+our @EXPORT_OK = qw.string.;
 
 sub string {
-	return $1 if ${$_[0]} =~ m.$_string.gc;
+	my ($string) = @_;
+	return $1 if $$string =~ m.$_string.gc;
 	return;
 }
 
